#!/bin/sh
# 環境省日本植生図 (自然環境保全基礎調査 3次メッシュ植生データ)の読みこみ & フォーマット変換 & 統合。
# 2004/03/05 Kenlo Nishida ver.0.1
# 2006/02/18 Kenlo Nishida ver.0.2  水田のカテゴリを追加。カテゴリを補間。
# 2013/12/13 Kenlo Nishida Nasahara ver.0.3
# 2022/02/18 Kenlo Nishida Nasahara Ver.0.4
#
# 略語
# LC: land cover
# MOE: Ministry of Environment 環境省
#
# data sourece:
# http://www.biodic.go.jp/dload/mesh_vg.html
# http://www.biodic.go.jp/kiso/vg/vg_kiso.html
#基準地域メッシュについて： http://www.biodic.go.jp/kiso/col_mesh.html
#地域メッシュの区分方法
#区画の種類 区分方法 緯度の間隔 経度の間隔 一辺の長さ 地図との関係
#第１次地域区画
#全国の地域を偶数緯度及びその間隔(120分）を３等分した緯度における緯線並びに１度ごとの経線とによって分割してできる区域
#40分 １度 約80km 20万分の１地勢図の１図葉の区画
#第２次地域区画
#第１次地域区画を緯線方向及び経線方向に８等分してできる区域
#5分 7分30秒 約10km ２万５千分の１地勢図の１図葉の区画
#基準地域メッシュ（第３次地域区画） 
#第２次地域区画を緯線方向及び経線方向に10等分してできる区域
#30秒 45秒 約1km 　
#(http://www.stat.go.jp/data/mesh/08-3s1.htm)

# basic tool (inserting a space to text)
gcc is_.c -o is_

# download & melt
wget http://www.biodic.go.jp/dload/veg/veg04m01.lzh
wget http://www.biodic.go.jp/dload/veg/veg05m01.lzh
wget http://www.biodic.go.jp/dload/veg/veg_c02.lzh
unar veg04m01.lzh
unar veg05m01.lzh
unar veg_c02.lzh

# conversion: mesh -> latitude & longitude
gcc mesh2latlon_.c -o mesh2latlon

echo "step 1"
cat ./veg05m01/veg05mesh.csv | awk 'NR>1{print}' | sed 's/"//g' | sed 's/,/ /' | ./is_ 6 | \
./is_ 4 | awk '{print $1,$2,$3}' | ./mesh2latlon | awk '{print $2,$1}' \
>latlon.txt

echo "step 2"
# extract vegetation types
#  植生タイプは、もともとveg_gunraku.csvに記述されている。
#  集約群落コードの先頭のAは10に変換
#  群落コードの末尾のA〜Oは1〜15に変換
cat ./veg05m01/veg05mesh.csv | awk 'NR>1{print}' | sed 's/"//g' | sed 's/,/ /' \
| perl -pe 's/\r\n/\n/' | awk '{print $2" 0"}'| ./is_ 5 | awk '{print $1,$2}' \
| sed 's/ A/ 1/'| sed 's/B/2/' | sed 's/C/3/' | sed 's/D/4/' | sed 's/E/5/' \
| sed 's/F/6/'  | sed 's/G/7/' | sed 's/H/8/' | sed 's/I/9/' | sed 's/J/10/' \
| sed 's/K/11/' | sed 's/L/12/'| sed 's/M/13/'|sed 's/N/14/' | sed 's/O/15/' \
| ./is_ 1 | sed 's/A/10/' | awk '{print $1,$1$2,$3}' > LC.txt

echo "step 3"
# 緯度経度と植生タイプの結合ファイルを作る
paste latlon.txt LC.txt >latlon_LC.txt

echo "step 4"
# 結合ファイルをラスターに変換。LC_MOE_level1, LC_MOE_level2, LC_MOE_level3というラスターファイル(ENVIヘッダーつき)ができる。
#  LC_MOE_level1: 植生区分コード
#  LC_MOE_level2: 集約群落コード
#  LC_MOE_level3: 群落コードの末尾のA〜Oを1〜15に変換したもの。
#  ラスターファイルは4バイト/ピクセル。位置とサイズはLC_MOE2rast.cの註釈を参照してください。
gcc LC_MOE2rast.c -o LC_MOE2rast
./LC_MOE2rast < latlon_LC.txt

echo "step 5"
#集約群落コードとMOD12のコードの対応表を抜きだす：
cat veg_syuyaku_MOD12.txt | awk 'NR>1{print $1, $3}' >table.txt
# MOD12 Land_Cover_Type_1
# ENF evergreen_needleleaf_forest         1
# EBF evergreen_broadleaf_forest          2
# DNF deciduous_needleleaf_forest         3
# DBF deciduous_broadleaf_forest          4
# MXF mixed_forests                       5
# CSH closed_shrubland                    6
# OSH open_shrublands                     7
# WSV woody_savannas                      8
# SVN savannas                            9
# GRS grasslands                         10
# PWT permanent_wetlands                 11
# CRP croplands                          12
# URB urban_and_built-up                 13
# MOS cropland_natural_vegetation_mosaic 14
# ICE snow_and_ice                       15
# BAR barren_or_sparsely_vegetated       16
# paddy field (not in MOD12)            253
# UNC unclassified                      254

echo "step 6"
#集約群落コードをMOD12のコードに統合
#集約群落コードに植生カテゴリが割り当てられていないものは、ひとつ前の番号の集約群落コード
#に対応する植生カテゴリを割り当てる(2006/02/18　西田）。
gcc LC_MOE_rast2MOD12.c -o LC_MOE_rast2MOD12
./LC_MOE_rast2MOD12 < LC_MOE_level2 > LC_MOE_MOD12cats

cat << EOF
output files:
LC_MOE_level1 + hdr file ... 植生区分コード
LC_MOE_level2 + hdr file ... 集約群落コード
LC_MOE_level3 + hdr file ... 群落コードの末尾のA〜Oを1〜15に変換したもの
LC_MOE_MOD12cats + hdr file ... integrated LC map in MODIS MOD12 map
EOF

